# Compile your JMC code on save! 
### Why?
Thats because wingedseal CEO of JMC refused to implement that feature. And i thought, why not?

![Proof](images/proof.png)
### How?
Just use the `jmcwatch` command while your terminal is in your jmc project. Every time you save any of your .jmc files it will run `jmc compile` automatically.
### Contact me here
discord: @amandin
telegram: @amwndin
